@@ -47,6 +47,7 @@ import org.tigris.subversion.svnclientadapter.ISVNNotifyListener;
 import org.tigris.subversion.svnclientadapter.ISVNProgressListener;
 import org.tigris.subversion.svnclientadapter.ISVNProperty;
 import org.tigris.subversion.svnclientadapter.ISVNStatus;
+import org.tigris.subversion.svnclientadapter.ISVNStatusCallback;
 import org.tigris.subversion.svnclientadapter.SVNBaseDir;
 import org.tigris.subversion.svnclientadapter.SVNClientException;
 import org.tigris.subversion.svnclientadapter.SVNDiffSummary;
@@ -428,7 +429,7 @@ public class CmdLineClientAdapter extends AbstractClientAdapter {
 		try {
 			if (message == null)
 				message = "";
-			_cmd.copy(toString(src), toString(dest), message, toString(rev));
+			_cmd.copy(toString(src), toString(dest), message, toString(rev), false);
 		} catch (CmdLineException e) {
 			throw SVNClientException.wrapException(e);
 		}
@@ -967,7 +968,7 @@ public class CmdLineClientAdapter extends AbstractClientAdapter {
 		try {
 			if (message == null)
 				message = "";
-			_cmd.copy(toString(srcPath), toString(destUrl), message, null);
+			_cmd.copy(toString(srcPath), toString(destUrl), message, null, false);
 		} catch (CmdLineException e) {
 			throw SVNClientException.wrapException(e);
 		}
@@ -979,7 +980,7 @@ public class CmdLineClientAdapter extends AbstractClientAdapter {
 	public void copy(SVNUrl srcUrl, File destPath, SVNRevision revision)
 		throws SVNClientException {
 		try {
-			_cmd.copy(toString(srcUrl), toString(destPath), null, toString(revision));
+			_cmd.copy(toString(srcUrl), toString(destPath), null, toString(revision), false);
 		} catch (CmdLineException e) {
 			throw SVNClientException.wrapException(e);
 		}
@@ -1695,9 +1696,13 @@ public class CmdLineClientAdapter extends AbstractClientAdapter {
 	public void copy(SVNUrl srcUrl, SVNUrl destUrl, String message,
 			SVNRevision revision, boolean makeParents)
 			throws SVNClientException {
-		// TODO Auto-generated method stub
-		notImplementedYet();
-		
+    try {
+      if (message == null)
+        message = "";
+      _cmd.copy(toString(srcUrl), toString(destUrl), message, toString(revision), makeParents);
+    } catch (CmdLineException e) {
+      throw SVNClientException.wrapException(e);
+    }
 	}
 
 	public void diff(SVNUrl target, SVNRevision pegRevision,
@@ -1918,4 +1923,54 @@ public class CmdLineClientAdapter extends AbstractClientAdapter {
 		return null;
 	}
 
+	@Override
+	public String getPostCommitError() {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	@Override
+	public ISVNStatus[] getStatus(File path, boolean descend, boolean getAll,
+			boolean contactServer, boolean ignoreExternals,
+			ISVNStatusCallback callback) throws SVNClientException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	@Override
+	public void propertySet(SVNUrl url, Number baseRev, String propertyName,
+			String propertyValue, String message) throws SVNClientException {
+		// TODO Auto-generated method stub
+		
+	}
+
+	@Override
+	public ISVNProperty[] getProperties(File path, boolean descend)
+			throws SVNClientException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	@Override
+	public ISVNProperty[] getProperties(SVNUrl url, SVNRevision revision,
+			SVNRevision peg, boolean recurse) throws SVNClientException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	@Override
+	public void switchToUrl(File path, SVNUrl url, SVNRevision revision,
+			SVNRevision pegRevision, int depth, boolean setDepth,
+			boolean ignoreExternals, boolean force, boolean ignoreAncestry)
+			throws SVNClientException {
+		// TODO Auto-generated method stub
+		
+	}
+
+	@Override
+	public void upgrade(File dir) throws SVNClientException {
+		// TODO Auto-generated method stub
+		
+	}
+
 }
