@@ -18,14 +18,12 @@
  ******************************************************************************/
 package org.tigris.subversion.svnclientadapter.javahl;
 
-import org.tigris.subversion.javahl.NodeKind;
-import org.tigris.subversion.javahl.Notify2;
-import org.tigris.subversion.javahl.NotifyAction;
-import org.tigris.subversion.javahl.NotifyInformation;
-import org.tigris.subversion.javahl.NotifyStatus;
-import org.tigris.subversion.javahl.Revision;
-import org.tigris.subversion.javahl.RevisionRange;
+import org.apache.subversion.javahl.ClientNotifyInformation;
+import org.apache.subversion.javahl.types.Revision;
+import org.apache.subversion.javahl.types.RevisionRange;
+import org.apache.subversion.javahl.callback.ClientNotifyCallback;
 import org.tigris.subversion.svnclientadapter.ISVNNotifyListener;
+import org.tigris.subversion.svnclientadapter.SVNConflictVersion.NodeKind;
 import org.tigris.subversion.svnclientadapter.SVNNotificationHandler;
 import org.tigris.subversion.svnclientadapter.utils.Messages;
 
@@ -41,7 +39,7 @@ import org.tigris.subversion.svnclientadapter.utils.Messages;
  * 
  *
  */
-public class JhlNotificationHandler extends SVNNotificationHandler implements Notify2 {
+public class JhlNotificationHandler extends SVNNotificationHandler implements ClientNotifyCallback {
     private boolean receivedSomeChange;
     private boolean sentFirstTxdelta;
     
@@ -65,23 +63,13 @@ public class JhlNotificationHandler extends SVNNotificationHandler implements No
     private static final int COMMIT_ACROSS_WC_COMPLETED = -11;
     private static final int ENDED_ABNORMAL = -1;
 
-    public void onNotify(NotifyInformation info) {
-
+    public void onNotify(ClientNotifyInformation info) {
         // for some actions, we don't want to call notifyListenersOfChange :
         // when the status of the target has not been modified 
         boolean notify = true;
 
         switch (info.getAction()) {
-        		case ENDED_ABNORMAL:
-        		   if (command == ISVNNotifyListener.Command.COMMIT)
-         		   logError(Messages.bind("notify.commit.abnormal")); //$NON-NLS-1$
-        		   else
-        		       logError(Messages.bind("notify.end.abnormal")); //$NON-NLS-1$
-        		   if (info.getErrMsg() != null)
-        			  logError(info.getErrMsg()); 
-                notify = false;                                
-                break;
-        	case NotifyAction.foreign_merge_begin :
+         	case foreign_merge_begin :
         		if (info.getMergeRange() != null) {
 	        		if (info.getMergeRange().getFromRevision().equals(info.getMergeRange().getToRevision()))
 	        			logMessage("--- Merging (from foreign repository) r" + info.getMergeRange().getFromRevision().toString() + " into " + info.getPath());
@@ -96,7 +84,7 @@ public class JhlNotificationHandler extends SVNNotificationHandler implements No
 	        	}
         		notify = false;
         		break;
-        	case NotifyAction.merge_begin :
+        	case merge_begin :
         		if (info.getMergeRange() != null) {
 	        		if (info.getMergeRange().getFromRevision().equals(info.getMergeRange().getToRevision()))
 	        			logMessage("--- Merging r" + info.getMergeRange().getFromRevision().toString() + " into " + info.getPath());
@@ -111,122 +99,141 @@ public class JhlNotificationHandler extends SVNNotificationHandler implements No
 	        	}
         		notify = false;
         		break;
-            case NotifyAction.skip :
-                logMessage(Messages.bind("notify.skipped", info.getPath())); //$NON-NLS-1$
-                notify = false;                                
+            case skip :
+            	notify = logSkipped(info, Messages.bind("notify.skipped", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.failed_lock: 
-            	if (info.getErrMsg() == null)
-            		logError(Messages.bind("notify.lock.failed", info.getPath())); //$NON-NLS-1$
-            	else
-            		logError(info.getErrMsg());
-                notify = false;
+            case update_skip_obstruction :
+            	notify = logSkipped(info, Messages.bind("notify.update.skip.obstruction", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.failed_unlock:
-            	if (info.getErrMsg() == null)
-            		logError(Messages.bind("notify.unlock.failed", info.getPath())); //$NON-NLS-1$
-            	else
-            		logError(info.getErrMsg());
-            	notify = false;
+            case update_skip_working_only :
+            	notify = logSkipped(info, Messages.bind("notify.update.skip.working.only", info.getPath())); //$NON-NLS-1$
+                break;  
+            case update_skip_access_denied :
+            	notify = logSkipped(info, Messages.bind("notify.update.skip.access.denied", info.getPath())); //$NON-NLS-1$
+                break;                  
+            case failed_lock: 
+            	notify = logFailedOperation(info, Messages.bind("notify.lock.failed", info.getPath())); //$NON-NLS-1$
+                break;
+            case failed_unlock:
+            	notify = logFailedOperation(info, Messages.bind("notify.unlock.failed", info.getPath())); //$NON-NLS-1$
             	break;
-            case NotifyAction.locked:
+            case locked:
                 if (info.getLock() != null && info.getLock().getOwner() != null)
                     logMessage(Messages.bind("notify.lock.other", info.getLock().getPath(), info.getLock().getOwner())); //$NON-NLS-1$
                 else
                     logMessage(Messages.bind("notify.lock", info.getPath())); //$NON-NLS-1$
         	    notify = false; // for JavaHL bug
             	break;
-            case NotifyAction.unlocked:
+            case unlocked:
                 logMessage(Messages.bind("notify.unlock", info.getPath())); //$NON-NLS-1$
             	notify = false; // for JavaHL bug
             	break;
-            case NotifyAction.update_delete :
+            case update_delete :
+            case update_shadowed_delete :
                 logMessage("D   " + info.getPath()); //$NON-NLS-1$
                 receivedSomeChange = true;
                 deletes += 1;
                 break;
-            case NotifyAction.update_replaced :
+            case update_replaced :
                 logMessage("R   " + info.getPath()); //$NON-NLS-1$
                 receivedSomeChange = true;
                 adds += 1;
                 deletes += 1;
                 break;
-            case NotifyAction.update_add :
+            case update_add :
+            case update_shadowed_add :
                 logMessage("A   " + info.getPath()); //$NON-NLS-1$
                 receivedSomeChange = true;
                 adds += 1;
                 break;
-            case NotifyAction.exists :
+            case exists :
                 logMessage("E   " + info.getPath()); //$NON-NLS-1$
                 receivedSomeChange = true;
                 exists += 1;
                 break;
-            case NotifyAction.restore :
+            case changelist_set :
+                logMessage(Messages.bind("notify.changelist.set", info.getPath())); //$NON-NLS-1$
+                notify = false;
+                break; 
+            case changelist_clear :
+                logMessage(Messages.bind("notify.changelist.clear", info.getPath())); //$NON-NLS-1$
+                notify = false;
+                break;  
+            case changelist_moved :
+                logMessage(Messages.bind("notify.changelist.moved", info.getPath())); //$NON-NLS-1$
+                notify = false;
+                break;                        
+            case restore :
                 logMessage(Messages.bind("notify.restored", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.revert :
+            case revert :
                 logMessage(Messages.bind("notify.reverted", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.failed_revert :
+            case failed_revert :
                 logError(Messages.bind("notify.revert.failed", info.getPath())); //$NON-NLS-1$
                 notify = false;
                 break;
-            case NotifyAction.resolved :
+            case resolved :
                 logMessage(Messages.bind("notify.resolved", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.add :
+            case add :
                 logMessage("A         " + info.getPath()); //$NON-NLS-1$
                 break;
-            case NotifyAction.delete :
+            case copy :
+                logMessage(Messages.bind("notify.copy", info.getPath())); //$NON-NLS-1$
+                notify = false;
+                break;                
+            case delete :
                 logMessage("D         " + info.getPath()); //$NON-NLS-1$
                 receivedSomeChange = true;
                 break;
-            case NotifyAction.tree_conflict :
+            case tree_conflict :
                 logError("  C " + info.getPath()); //$NON-NLS-1$
                 receivedSomeChange = true;
                 treeConflicts += 1;
             	break;
-            case NotifyAction.update_update :
+            case update_update :
+            case update_shadowed_update :
                 boolean error = false;
-                if (!((info.getKind() == NodeKind.dir)
-                    && ((info.getPropState() == NotifyStatus.inapplicable)
-                        || (info.getPropState() == NotifyStatus.unknown)
-                        || (info.getPropState() == NotifyStatus.unchanged)))) {
+                if (!((info.getKind().ordinal() == NodeKind.directory)
+                    && ((info.getPropState() == ClientNotifyInformation.Status.inapplicable)
+                        || (info.getPropState() == ClientNotifyInformation.Status.unknown)
+                        || (info.getPropState() == ClientNotifyInformation.Status.unchanged)))) {
                     receivedSomeChange = true;
                     char[] statecharBuf = new char[] { ' ', ' ' };
-                    if (info.getKind() == NodeKind.file) {
-                        if (info.getContentState() == NotifyStatus.conflicted) {
+                    if (info.getKind().ordinal() == NodeKind.file) {
+                        if (info.getContentState() == ClientNotifyInformation.Status.conflicted) {
                             statecharBuf[0] = 'C';
                             conflicts += 1;
                             error = true;
                         }
-                        else if (info.getContentState() == NotifyStatus.merged) {
+                        else if (info.getContentState() == ClientNotifyInformation.Status.merged) {
                             statecharBuf[0] = 'G';
                             merges += 1;
                             error = true;
                         }
-                        else if (info.getContentState() == NotifyStatus.changed) {
+                        else if (info.getContentState() == ClientNotifyInformation.Status.changed) {
                             statecharBuf[0] = 'U';
                             updates += 1;
                         }
-                        else if (info.getContentState() == NotifyStatus.unchanged && info.getPropState() < NotifyStatus.obstructed)
+                        else if (info.getContentState() == ClientNotifyInformation.Status.unchanged && info.getPropState().ordinal() < ClientNotifyInformation.Status.obstructed.ordinal())
                             break;
                     }
-                    if (info.getPropState() == NotifyStatus.conflicted) {
+                    if (info.getPropState() == ClientNotifyInformation.Status.conflicted) {
                         statecharBuf[1] = 'C';
                         propConflicts += 1;
                         error = true;
                     }
-                    else if (info.getPropState() == NotifyStatus.merged) {
+                    else if (info.getPropState() == ClientNotifyInformation.Status.merged) {
                         statecharBuf[1] = 'G';
                         propMerges += 1;
                         error = true;
                     }
-                    else if (info.getPropState() == NotifyStatus.changed) {
+                    else if (info.getPropState() == ClientNotifyInformation.Status.changed) {
                         statecharBuf[1] = 'U';
                         propUpdates += 1;
                     }
-                    if (info.getContentState() == NotifyStatus.unknown && info.getPropState() == NotifyStatus.unknown)
+                    if (info.getContentState() == ClientNotifyInformation.Status.unknown && info.getPropState() == ClientNotifyInformation.Status.unknown)
                     	break;
                     if (error)
                         logError("" + statecharBuf[0] + statecharBuf[1] + "  " + info.getPath());                       //$NON-NLS-1$ //$NON-NLS-2$
@@ -234,11 +241,14 @@ public class JhlNotificationHandler extends SVNNotificationHandler implements No
                         logMessage("" + statecharBuf[0] + statecharBuf[1] + "  " + info.getPath());                       //$NON-NLS-1$ //$NON-NLS-2$
                 }
                 break;
-            case NotifyAction.update_external :
+            case update_external :
                 logMessage(Messages.bind("notify.update.external", info.getPath())); //$NON-NLS-1$
             	inExternal = true;
                 break;
-            case NotifyAction.update_completed :
+            case update_external_removed :
+                logMessage(Messages.bind("notify.update.external.removed", info.getPath())); //$NON-NLS-1$
+                break;                
+            case update_completed :
                 notify = false;
                 if (info.getRevision() >= 0) {
                     logRevision( info.getRevision(), info.getPath() );
@@ -280,12 +290,12 @@ public class JhlNotificationHandler extends SVNNotificationHandler implements No
                     }  
                 }
                 break;
-            case NotifyAction.status_external :
+            case status_external :
               if (!skipCommand())
                 logMessage(Messages.bind("notify.status.external", info.getPath())); //$NON-NLS-1$
               notify = false;
               break;
-            case NotifyAction.status_completed :
+            case status_completed :
               notify = false;
               if (info.getRevision() >= 0) {
                 logRevision(info.getRevision(), info.getPath());
@@ -293,63 +303,148 @@ public class JhlNotificationHandler extends SVNNotificationHandler implements No
                     logMessage(Messages.bind("notify.status.revision", Long.toString(info.getRevision()))); //$NON-NLS-1$
               }
               break;                
-            case NotifyAction.commit_modified :
+            case commit_modified :
                 logMessage(Messages.bind("notify.commit.modified", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.commit_added :
+            case commit_added :
+            case commit_copied :
                 logMessage(Messages.bind("notify.commit.add", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.commit_deleted :
+            case commit_deleted :
                 logMessage(Messages.bind("notify.commit.delete", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.commit_replaced :
+            case commit_replaced :
+            case commit_copied_replaced :
                 logMessage(Messages.bind("notify.commit.replace", info.getPath())); //$NON-NLS-1$
                 break;
-            case NotifyAction.commit_postfix_txdelta :
+            case commit_postfix_txdelta :
                 notify = false;
                 if (!sentFirstTxdelta) {
                     logMessage(Messages.bind("notify.commit.transmit")); //$NON-NLS-1$
                     sentFirstTxdelta = true;
                 }
-                break;                              
-            case COMMIT_ACROSS_WC_COMPLETED :
-                notify = false;
-                logCompleted(Messages.bind("notify.commit", Long.toString(info.getRevision()))); //$NON-NLS-1$
-                break;
-            case NotifyAction.property_added:
+                break;  
+            case url_redirect :
+            	break;
+            case property_added:
             	logMessage(Messages.bind("notify.property.set", info.getPath())); //$NON-NLS-1$
             	break;
-            case NotifyAction.property_modified:
+            case property_modified:
             	logMessage(Messages.bind("notify.property.set", info.getPath())); //$NON-NLS-1$
             	break; 
-            case NotifyAction.property_deleted:
+            case property_deleted:
             	logMessage(Messages.bind("notify.property.deleted", info.getPath())); //$NON-NLS-1$
             	break;
-            case NotifyAction.property_deleted_nonexistent:
+            case property_deleted_nonexistent:
             	notify = false;
             	logMessage(Messages.bind("notify.property.deleted.nonexistent")); //$NON-NLS-1$
             	break; 
-            case NotifyAction.revprop_set:
+            case revprop_set:
             	notify = false;
             	logMessage(Messages.bind("notify.revision.property.set")); //$NON-NLS-1$
             	break;  
-            case NotifyAction.revprop_deleted:
+            case revprop_deleted:
             	notify = false;
             	logMessage(Messages.bind("notify.revision.property.deleted")); //$NON-NLS-1$
             	break;    
-            case NotifyAction.merge_completed:
-            	break;                   	
-            case NotifyAction.blame_revision:
+            case merge_completed:
             	break;                   	
+            case blame_revision:
+            	break;
+            case update_started:
+            	break;
+            case merge_record_info:
+            	logMessage(Messages.bind("notify.merge.record.info", info.getPath())); //$NON-NLS-1$
+            	propUpdates += 1;
+            	break;
+            case merge_record_info_begin:
+            	break;
+            case merge_elide_info:
+            	break;
+            case patch:
+            	notify = false;
+            	logMessage(Messages.bind("notify.patch")); //$NON-NLS-1$
+            	break;
+            case patch_applied_hunk:
+            	logMessage(Messages.bind("notify.patch.applied.hunk", info.getPath())); //$NON-NLS-1$
+            	break;  
+            case patch_rejected_hunk:
+            	notify = logFailedOperation(info, Messages.bind("notify.patch.rejected.hunk", info.getPath()));
+            	break;
+            case patch_hunk_already_applied:
+            	notify = logFailedOperation(info, Messages.bind("notify.patch.hunk.already.applied", info.getPath()));
+            	break;                       	
+            case upgraded_path:
+            	logMessage(Messages.bind("notify.upgraded.path", info.getPath())); //$NON-NLS-1$
+            	break;
+            case failed_external: 
+            	notify = logFailedOperation(info, Messages.bind("notify.external", info.getPath())); //$NON-NLS-1$
+                break;     
+            case failed_conflict: 
+            	notify = logFailedOperation(info, Messages.bind("notify.conflict", info.getPath())); //$NON-NLS-1$
+                break;  
+            case failed_missing: 
+            	notify = logFailedOperation(info, Messages.bind("notify.missing", info.getPath())); //$NON-NLS-1$
+                break;                      
+            case failed_out_of_date: 
+            	notify = logFailedOperation(info, Messages.bind("notify.out.of.date", info.getPath())); //$NON-NLS-1$
+                break; 
+            case failed_no_parent:
+            	notify = logFailedOperation(info, Messages.bind("notify.no.parent")); //$NON-NLS-1$
+                break;                
+            case failed_locked:
+            	notify = logFailedOperation(info, Messages.bind("notify.locked", info.getPath())); //$NON-NLS-1$
+                break;
+            case failed_forbidden_by_server:
+            	notify = logFailedOperation(info, Messages.bind("notify.forbidden.by.server")); //$NON-NLS-1$
+                break; 
+            case path_nonexistent:
+            	notify = logFailedOperation(info, Messages.bind("notify.path.nonexistent", info.getPath())); //$NON-NLS-1$
+                break;   
+            case exclude:
+            	logMessage(Messages.bind("notify.exclude", info.getPath()));
+            	break;
             default:
+            	if (info.getAction().ordinal() == ENDED_ABNORMAL) {
+            		if (command == ISVNNotifyListener.Command.COMMIT)
+            			logError(Messages.bind("notify.commit.abnormal")); //$NON-NLS-1$
+            		else
+            			logError(Messages.bind("notify.end.abnormal")); //$NON-NLS-1$
+            		if (info.getErrMsg() != null)
+            			logError(info.getErrMsg()); 
+            		notify = false;                                
+            		break;
+            	}
+            	if (info.getAction().ordinal() == COMMIT_ACROSS_WC_COMPLETED) {
+                    notify = false;
+                    logCompleted(Messages.bind("notify.commit", Long.toString(info.getRevision()))); //$NON-NLS-1$
+                    break;
+            	}
             	logMessage("Unknown action received: " + info.getAction());
                 	
         }
+
         if (notify) {
             // only when the status changed
             notifyListenersOfChange(info.getPath(), JhlConverter.convertNodeKind(info.getKind()));                
         }
     }
+    
+    private boolean logFailedOperation(ClientNotifyInformation info, String defaultErrorMessage) {
+    	if (info.getErrMsg() == null)
+    		logError(defaultErrorMessage);
+    	else
+    		logError(info.getErrMsg());
+    	return false;
+    }
+    
+    private boolean logSkipped(ClientNotifyInformation info, String defaultErrorMessage)	 {
+    	if (info.getErrMsg() == null)
+    		logMessage(defaultErrorMessage);
+    	else
+    		logError(info.getErrMsg());
+    	return false;    	
+    }
 
     public void setCommand(int command) {
         receivedSomeChange = false;
@@ -481,4 +576,4 @@ public class JhlNotificationHandler extends SVNNotificationHandler implements No
         }
         logStats();
     }
-}
+}
\ No newline at end of file
