@@ -23,7 +23,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.List;
 
-
 /**
  * High level API for Subversion
  * 
@@ -202,6 +201,8 @@ public interface ISVNClientAdapter {
 	public abstract long[] commitAcrossWC(File[] paths, String message, boolean recurse, boolean keepLocks, boolean atomic)
 		throws SVNClientException;
 	
+	public String getPostCommitError();
+	
 	/**
 	 * List directory entries of a URL
 	 * @param url
@@ -359,6 +360,25 @@ public interface ISVNClientAdapter {
 	 */
 	public abstract ISVNStatus[] getStatus(File path, boolean descend, boolean getAll, boolean contactServer, boolean ignoreExternals)
 	throws SVNClientException;
+	
+	/**
+	 * Returns the status of path and its children.
+     * If descend is true, recurse fully, else do only immediate children.
+     * If getAll is set, retrieve all entries; otherwise, retrieve only 
+     * "interesting" entries (local mods and/or out-of-date). Use the
+     * contactServer option to get server change information.
+     *
+	 * @param path File to gather status.
+     * @param descend get recursive status information
+     * @param getAll get status information for all files
+     * @param contactServer contact server to get remote changes
+     * @param ignoreExternals if externals are ignored during status
+     * @param callback callback to collect statuses
+	 * @return a Status
+     * @throws SVNClientException
+	 */
+	public abstract ISVNStatus[] getStatus(File path, boolean descend, boolean getAll, boolean contactServer, boolean ignoreExternals, ISVNStatusCallback callback)
+	throws SVNClientException;
 
 	/**
 	 * copy and schedule for addition (with history)
@@ -972,6 +992,23 @@ public interface ISVNClientAdapter {
 		String propertyValue,
 		boolean recurse)
 		throws SVNClientException;
+	
+	/**
+	 * set a property
+	 * @param url
+	 * @param baseRev
+	 * @param propertyName
+	 * @param propertyValue
+	 * @param recurse
+	 * @throws SVNClientException
+	 */
+	public abstract void propertySet(
+		SVNUrl url,
+		SVNRevision.Number baseRev,
+		String propertyName,
+		String propertyValue,
+		String message)
+		throws SVNClientException;
 
 	/**
 	 * set a property using the content of a file 
@@ -1408,6 +1445,26 @@ public interface ISVNClientAdapter {
      */    
 	public abstract ISVNProperty[] getProperties(File path) throws SVNClientException;
 	
+    /**
+     * Get all the properties for the given file or dir
+     * @param path
+     * @param descend get properties recursively
+     * @return the properties for the given url
+     * @throws SVNClientException
+     */    
+	public abstract ISVNProperty[] getProperties(File path, boolean descend) throws SVNClientException;
+	
+    /**
+     * Get all the properties for the given url
+	 * @param url
+	 * @param revision
+	 * @param peg
+	 * @param recurse
+	 * @return information about an URL.
+	 * @throws SVNClientException
+	 */
+	public abstract ISVNProperty[] getProperties(SVNUrl url, SVNRevision revision, SVNRevision peg, boolean recurse) throws SVNClientException;
+	
     /**
      * Get all the properties for the given url
 	 * @param url
@@ -1558,7 +1615,24 @@ public interface ISVNClientAdapter {
      * @param force
      * @throws SVNClientException
      */
-    public void switchToUrl(File path, SVNUrl url, SVNRevision revision, SVNRevision pegRevision, int depth, boolean setDepth, boolean ignoreExternals, boolean force) throws SVNClientException;            
+    public void switchToUrl(File path, SVNUrl url, SVNRevision revision, SVNRevision pegRevision, int depth, boolean setDepth, boolean ignoreExternals, boolean force) throws SVNClientException;  
+    
+    /**
+     * Update the working copy to mirror a new URL within the repository.
+     * This behaviour is similar to 'svn update', and is the way to
+     * move a working copy to a branch or tag within the same repository.
+     * @param url
+     * @param path
+     * @param revision
+     * @param pegRevision
+     * @param depth
+     * @param setDepth
+     * @param ignoreExternals
+     * @param force
+     * @param ignoreAncestry
+     * @throws SVNClientException
+     */
+    public void switchToUrl(File path, SVNUrl url, SVNRevision revision, SVNRevision pegRevision, int depth, boolean setDepth, boolean ignoreExternals, boolean force, boolean ignoreAncestry) throws SVNClientException;                
     
     /**
      * Set the configuration directory.
@@ -1573,6 +1647,13 @@ public interface ISVNClientAdapter {
      * @throws SVNClientException
      */
     public abstract void cleanup(File dir) throws SVNClientException;
+    
+    /**
+     * Recursively upgrade a working copy to a new metadata storage format.
+     * @param dir
+     * @throws SVNClientException
+     */    
+    public abstract void upgrade(File dir) throws SVNClientException;
 
     /**
      * Merge changes from two paths into a new local path.
